@@ -1096,7 +1096,7 @@ class WordToken(models.Model):
                 outline['FollSemPred'] = self.getFollSemPred()
                 outline['ImmedFollSemPred'] = self.getImmediateFollSemPred()
                 outline['IntermedFollSemPred'] = self.getIntermedFollSemPred()
-            wanted_fields.extend(['FollSemPred','ImmedFollSemPred','IntermedFollSemPred']])
+            wanted_fields.extend(['FollSemPred','ImmedFollSemPred','IntermedFollSemPred'])
         if form['placeInDialog']:
             if 'placeInDialog' not in outline:
                 outline['placeInDialog'] = self.getDialogPlace()
